@@ -84,6 +84,25 @@ auth_dn_is_good (const gchar * authdn)
 }
 
 
+/**
+ * @brief Returns path to users directory.
+ *
+ * @param[in]  username  The users name.
+ *
+ * @return Path to users directory. Caller has to free with g_free. NULL if
+ *         parameter is NULL.
+ */
+static gchar *
+user_dir_path (const gchar * username)
+{
+  if (username == NULL)
+    return NULL;
+
+  return g_build_filename (OPENVAS_STATE_DIR, "users-remote", "ldap", username,
+                           NULL);
+}
+
+
 /**
  * @brief Create a new ldap authentication schema and info.
  *
@@ -197,7 +216,6 @@ ldap_auth_bind (const gchar * host, const gchar * userdn,
   LDAP *ldap = NULL;
   int ldap_return = 0;
   int ldapv3 = 3;
-  int res = 0;
   gchar *ldapuri = NULL;
   struct berval credential;
 
@@ -205,13 +223,14 @@ ldap_auth_bind (const gchar * host, const gchar * userdn,
     return NULL;
 
   if (force_starttls == FALSE)
-    g_warning ("Allowed plaintext LDAP authentication");
+    g_warning ("Allowed plaintext LDAP authentication.");
 
   ldapuri = g_strconcat ("ldap://", host, NULL);
-  ldap_initialize (&ldap, ldapuri);
+
+  ldap_return = ldap_initialize (&ldap, ldapuri);
   g_free (ldapuri);
 
-  if (ldap == NULL || res != LDAP_SUCCESS)
+  if (ldap == NULL || ldap_return != LDAP_SUCCESS)
     {
       g_warning ("Could not open LDAP connection for authentication.");
       return NULL;
@@ -221,7 +240,7 @@ ldap_auth_bind (const gchar * host, const gchar * userdn,
   ldap_return = ldap_set_option (ldap, LDAP_OPT_PROTOCOL_VERSION, &ldapv3);
   if (ldap_return != LDAP_SUCCESS)
     {
-      g_warning ("Could not set ldap protocol version to 3: %s.",
+      g_warning ("Aborting, could not set ldap protocol version to 3: %s.",
                  ldap_err2string (ldap_return));
       return NULL;
     }
@@ -416,6 +435,7 @@ ldap_auth_query_rules (LDAP * ldap, ldap_auth_info_t auth_info,
   gchar *rule = NULL;
   int ruletype = -1;
   LDAPMessage *result, *result_it;
+  gchar *user_dir = user_dir_path (username);
 
   int res = ldap_search_ext_s (ldap, dn /* base */ , LDAP_SCOPE_BASE,
                                NULL /* filter */ , attrs, 0 /* attrsonly */ ,
@@ -423,10 +443,18 @@ ldap_auth_query_rules (LDAP * ldap, ldap_auth_info_t auth_info,
                                LDAP_NO_LIMIT,   /* timeout */
                                LDAP_NO_LIMIT,   /* sizelimit */
                                &result);
+
+  // Ensure that rules directory exists in every case.
+  openvas_auth_mkrulesdir (user_dir);
+
   if (res != LDAP_SUCCESS)
     {
       g_debug ("The rule/ruletype of an ldap user could not be found: %s\n",
                ldap_err2string (res));
+      g_debug ("Storing default rules.");
+      openvas_auth_store_user_rules (user_dir, rule, ruletype);
+      g_free (user_dir);
+
       return -1;
     }
 
@@ -468,15 +496,9 @@ ldap_auth_query_rules (LDAP * ldap, ldap_auth_info_t auth_info,
 
       // Save the rules
       if (ruletype == -1)
-        g_warning ("No ruletype specified!");
-      else
-        {
-          gchar *user_dir = g_build_filename (OPENVAS_STATE_DIR,
-                                              "users-remote", "ldap",
-                                              username, NULL);
-          openvas_auth_store_user_rules (user_dir, rule, ruletype);
-          g_free (user_dir);
-        }
+        g_warning ("No ruletype specified, using defaults");
+
+      openvas_auth_store_user_rules (user_dir, rule, ruletype);
 
       g_free (rule);
 
@@ -488,8 +510,10 @@ ldap_auth_query_rules (LDAP * ldap, ldap_auth_info_t auth_info,
   else                          // No such attribute(s)
     {
       g_debug ("User has no rule/ruletype, did not find the attributes.");
+      openvas_auth_store_user_rules (user_dir, rule, ruletype);
     }
 
+  g_free (user_dir);
   ldap_msgfree (result);
 
   /** @todo proper returns */
@@ -510,7 +534,7 @@ ldap_auth_query_rules (LDAP * ldap, ldap_auth_info_t auth_info,
  *         +2 if user is "admin".
  */
 int
-ldap_auth_query_role (LDAP * ldap, ldap_auth_info_t auth_info, gchar * dn)
+ldap_auth_query_role (LDAP * ldap, ldap_auth_info_t auth_info, const gchar * dn)
 {
   char *attrs[] = { auth_info->role_attribute, NULL };
   char *attr_it = NULL;
@@ -626,9 +650,7 @@ ldap_authenticate (const gchar * username, const gchar * password,
       if (ldap_auth_query_rules (ldap, info, dn, username) == -1)
         g_warning ("Users rules could not be found on ldap directory.");
       // If user is admin, mark it so.
-      gchar *user_dir_name = g_build_filename (OPENVAS_STATE_DIR,
-                                               "users-remote", "ldap",
-                                               username, NULL);
+      gchar *user_dir_name = user_dir_path (username);
       openvas_set_user_role (username, (role == 2) ? "Admin" : "User",
                              user_dir_name);
       g_free (user_dir_name);
