@@ -129,10 +129,14 @@ renice_myself ()
 
   if (pid != cpid)
     {
+      int renice_result;
       if (nice (0) >= 10)
         return;
       pid = cpid;
-      nice (1);
+      renice_result = nice (1);
+      // @todo: Check value if renice_result to see if it was successful.
+      // Keep in mind that even -1 can mean success here; see man page of nice
+      // for details.
     }
 }
 
@@ -1635,7 +1639,7 @@ write_stream_connection4 (int fd, void *buf0, int n, int i_opt)
 
 #if DEBUG_SSL > 8
   fprintf (stderr,
-           "> write_stream_connection(%d, 0x%x, %d, 0x%x) \tE=%d 0=0x%x\n", fd,
+           "> write_stream_connection(%d, %s, %d, 0x%x) \tE=%d 0=0x%x\n", fd,
            buf, n, i_opt, fp->transport, fp->options);
 #endif
 
@@ -1910,7 +1914,7 @@ get_encaps_through (int code)
 }
 
 static int
-open_socket (struct sockaddr *paddr, int port, int type, int protocol,
+open_socket (struct sockaddr *paddr, int type, int protocol,
              int timeout, int len)
 {
   fd_set fd_w;
@@ -2036,7 +2040,7 @@ open_sock_opt_hn (const char *hostname, unsigned int port, int type,
       addr.sin_family = AF_INET;
       addr.sin_port = htons ((unsigned short) port);
       addr.sin_addr.s_addr = in6addr.s6_addr32[3];
-      return open_socket ((struct sockaddr *) &addr, port, type, protocol,
+      return open_socket ((struct sockaddr *) &addr, type, protocol,
                           timeout, sizeof (struct sockaddr_in));
     }
   else
@@ -2045,7 +2049,7 @@ open_sock_opt_hn (const char *hostname, unsigned int port, int type,
       addr6.sin6_family = AF_INET6;
       addr6.sin6_port = htons ((unsigned short) port);
       memcpy (&addr6.sin6_addr, &in6addr, sizeof (struct in6_addr));
-      return open_socket ((struct sockaddr *) &addr6, port, type, protocol,
+      return open_socket ((struct sockaddr *) &addr6, type, protocol,
                           timeout, sizeof (struct sockaddr_in6));
     }
 
@@ -2340,7 +2344,7 @@ open_sock_option (struct arglist *args, unsigned int port, int type,
       addr.sin_family = AF_INET;
       addr.sin_port = htons ((unsigned short) port);
       addr.sin_addr.s_addr = t->s6_addr32[3];
-      return open_socket ((struct sockaddr *) &addr, port, type, protocol,
+      return open_socket ((struct sockaddr *) &addr, type, protocol,
                           timeout, sizeof (struct sockaddr_in));
     }
   else
@@ -2349,7 +2353,7 @@ open_sock_option (struct arglist *args, unsigned int port, int type,
       addr6.sin6_family = AF_INET6;
       addr6.sin6_port = htons ((unsigned short) port);
       memcpy (&addr6.sin6_addr, t, sizeof (struct in6_addr));
-      return open_socket ((struct sockaddr *) &addr6, port, type, protocol,
+      return open_socket ((struct sockaddr *) &addr6, type, protocol,
                           timeout, sizeof (struct sockaddr_in6));
     }
 
