@@ -58,30 +58,36 @@
  * @file misc/openvas_auth.c
  *
  * @brief Authentication mechanisms used by openvas-manager and
- * @brief openvas-administrator.
+ * openvas-administrator.
  *
- * Two authentication mechanisms are supported:
+ * @section authentication_mechanisms Authentication Mechanisms
+ *
+ * Three authentication mechanisms are supported:
  *  - local file authentication. The classical authentication mechanism to
  *    authenticate against files (in PREFIX/var/lib/openvas/users).
  *  - remote ldap authentication. To authenticate against a remote ldap
  *    directory server.
+ *  - remote ads authentication. To authenticate against a remote ADS (active
+ *    directory server).
  *
- * Also a mixture of both can be used. To do so, a configuration file
+ * Also a mixture can be used. To do so, a configuration file
  * (PREFIX/var/lib/openvas/.auth.conf) has to be used and the authentication
  * system has to be initialised with a call to \ref openvas_auth_init and can
- * be freed with \ref openvas_tear_down .
+ * be freed with \ref openvas_auth_tear_down .
  *
- * The configuration file allows to specify details of a remote ldap
+ * The configuration file allows to specify details of a remote ldap and/or ads
  * authentication and to assign an "order" value to the specified
  * authentication mechanisms. Mechanisms with a lower order will be tried
  * first.
  *
+ * @section user_directories User Directories
+ *
  * Each user has a directory somewhere under OPENVAS_STATE_DIR.
  * The directories of locally authenticated users reside under
  * OPENVAS_STATE_DIR/users .
  * The directory of remotely authenticated users reside under
  * OPENVAS_STATE_DIR/users-remote/[method] , where [method] currently can only
- * be "ldap".
+ * be "ldap" or "ads".
  *
  * A users directory will contain:
  *
@@ -94,9 +100,6 @@
  *           contain knowledge bases saved by the openvas-scanner process.
  */
 
-/** @todo Abondon OPENVAS_USER_DIR, use OPENVAS_STATE_DIR + "users" or
- *        "users-remote/[method]" instead. */
-
 
 /**
  * @brief Numerical representation of the supported authentication methods.
@@ -423,9 +426,9 @@ openvas_auth_write_config (GKeyFile * key_file)
       g_key_file_set_value (new_conffile, "method:ldap", "role-admin-values",
                             "admin");
       g_key_file_set_value (new_conffile, "method:ldap", "ruletype-attribute",
-                            "x-gsm-ruletype");
+                            "x-gsm-accessruletype");
       g_key_file_set_value (new_conffile, "method:ldap", "rule-attribute",
-                            "x-gsm-rule");
+                            "x-gsm-accessrule");
     }
 
   // ADS Configuration
@@ -999,21 +1002,63 @@ openvas_user_uuid (const char *name)
  *
  * @param username Username.
  *
+ * @warning No "sharp" test is performed, as it is possible to have multiple
+ *          users with the same name (in order to allow integration of remote
+ *          authentication sources). Would need the uuid here to fix this
+ *          behaviour.
+ *
  * @return 1 user has administrative privileges, 0 user does not have
  * administrative privileges
  */
 int
 openvas_is_user_admin (const gchar * username)
 {
-  gchar *file_name = g_build_filename (OPENVAS_USERS_DIR,
-                                       username,
+  gchar *dir_name = g_build_filename (OPENVAS_USERS_DIR, username, NULL);
+  gchar *file_name = g_build_filename (dir_name,
                                        "isadmin",
                                        NULL);
-  gboolean file_exists = g_file_test (file_name, G_FILE_TEST_EXISTS);
-
-  /** @todo Resolve remote authentication case, need another function parameter. */
+  gboolean file_exists = FALSE;
+  if (g_file_test (dir_name, G_FILE_TEST_IS_DIR))
+    {
+      if (g_file_test (file_name, G_FILE_TEST_IS_REGULAR))
+        {
+          g_free (file_name);
+          g_free (dir_name);
+          return 1;
+        }
+      g_free (file_name);
+      g_free (dir_name);
+      return 0;
+    }
 
+  g_free (dir_name);
   g_free (file_name);
+
+  // Remote case.
+  if (file_exists == FALSE && (initialized == TRUE && authenticators != NULL))
+    {
+      // Try each authenticator in the list.
+      GSList *item = authenticators;
+      while (item)
+        {
+          authenticator_t authent = (authenticator_t) item->data;
+          file_name = g_build_filename (OPENVAS_STATE_DIR,
+                                        "users-remote",
+                                        authentication_methods[authent->method],
+                                        username,
+                                        "isadmin",
+                                        NULL);
+
+          if (g_file_test (file_name, G_FILE_TEST_EXISTS) == TRUE)
+            {
+              g_free (file_name);
+              return 1;
+            }
+          g_free (file_name);
+          item = g_slist_next (item);
+        }
+    }
+
   return file_exists;
 }
 
@@ -1144,7 +1189,8 @@ openvas_auth_user_uuid_rules (const gchar * username, const gchar * user_uuid,
 
 
 /**
- * @brief Get host access rules for a certain user.
+ * @brief Get host access rules for a certain user for file-based ("classic")
+ * @brief authentication.
  *
  * @deprecated  Use \ref openvas_auth_user_uuid_rules where possible (need to
  *              know the uuid of user). Use \ref openvas_authenticate_uuid to
@@ -1158,9 +1204,6 @@ openvas_auth_user_uuid_rules (const gchar * username, const gchar * user_uuid,
 int
 openvas_auth_user_rules (const gchar * username, gchar ** rules)
 {
-  /** @todo Resolve issue stemming from multiple users with the same name, but
-   *        authenticated differently. e.g. memorize rules while authenticating
-   *        via remote service. Or, pass password or uuid in here. */
   // File based: Get content of prefix/lib/openvas/users/user/auth/rules file
   GError *error = NULL;
   gchar *rules_file = g_build_filename (OPENVAS_USERS_DIR,
@@ -1182,14 +1225,50 @@ openvas_auth_user_rules (const gchar * username, gchar ** rules)
   return 1;
 }
 
+
+/**
+ * @brief Creates the directory for the users rules (userdir/auth), if it does
+ * @brief not yet exist.
+ *
+ * @warning Due to access () system calls nested in employed GLib functions,
+ * @warning this function might behave differently than expected in setuid
+ * @warning binaries.
+ *
+ * @param[in]  user_dir_name  The users directory.
+ *
+ * @return 0 if directory existed or was created, -1 if it could not be
+ *         created.
+ */
+int
+openvas_auth_mkrulesdir (const gchar * user_dir_name)
+{
+  int mkdir_result = 0;
+  gchar * auth_dir_name = g_build_filename (user_dir_name, "auth", NULL);
+
+  mkdir_result = g_mkdir_with_parents (auth_dir_name, 0700);
+  g_free (auth_dir_name);
+
+  if (mkdir_result != 0)
+    {
+      g_warning ("Users rules directory could not be created.");
+      return -1;
+    }
+
+  return 0;
+}
+
+
 /**
  * @brief Stores the rules for a user.
  *
  * The rules will be saved in a file in \ref user_dir_name /auth/rules .
+ * This directory has to exist prior to this function call, otherwise the
+ * file will not be written and -1 will be returned.
  *
  * @param[in]  user_dir_name  Directory under wich the autch/rules file will
  *                            be placed.
  * @param[in]  hosts          The hosts the user is allowed/forbidden to scan.
+ *                            Can be NULL, then defaults to allow-all.
  * @param[in]  hosts_allow    Whether access to \ref hosts is allowed (!=0) or
  *                            forbidden (0).
  *
@@ -1201,7 +1280,6 @@ openvas_auth_store_user_rules (const gchar * user_dir_name, const gchar * hosts,
 {
   GError *error = NULL;
   gchar *user_rules_file_name = NULL;
-  gchar *auth_dir_name = NULL;
   GString *rules = g_string_new (RULES_FILE_HEADER);
   if (hosts && strlen (hosts))
     {
@@ -1229,15 +1307,8 @@ openvas_auth_store_user_rules (const gchar * user_dir_name, const gchar * hosts,
       g_strfreev (split);
     }
 
-  auth_dir_name = g_build_filename (user_dir_name, "auth", NULL);
   // Put the rules in auth/rules.
-  user_rules_file_name = g_build_filename (auth_dir_name, "rules", NULL);
-
-  // Create the directories if they do not exist
-  if (g_mkdir_with_parents (auth_dir_name, 0700) != 0)
-    g_warning ("user directory could not be created");
-
-  g_free (auth_dir_name);
+  user_rules_file_name = g_build_filename (user_dir_name, "auth", "rules", NULL);
 
   if (!g_file_set_contents (user_rules_file_name, rules->str, -1, &error))
     {
