@@ -23,9 +23,6 @@
 #include <arpa/inet.h>
 #include <sys/ioctl.h>
 #include <netdb.h>
-#ifdef HAVE_SYS_SOCKIO_H
-#include <sys/sockio.h>
-#endif
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
@@ -37,7 +34,6 @@
 #include "pcap_openvas.h"
 #include "system_internal.h"
 #include "network.h"
-#include "config.h"
 
 #define MAXROUTES 1024
 
@@ -682,6 +678,9 @@ v6_getinterfaces (int *howmany)
     {
       for (ifa = ifaddr; ifa != NULL; ifa = ifa->ifa_next)
         {
+          if (ifa->ifa_addr == NULL)
+              continue;
+
           family = ifa->ifa_addr->sa_family;
           if (family == AF_INET)
             {
@@ -770,15 +769,7 @@ getinterfaces (int *howmany)
     printf
       ("getinterfaces: SIOCGIFCONF claims you have no network interfaces!\n");
 
-#ifdef HAVE_SOCKADDR_SA_LEN
-  len = ((struct ifreq *) buf)->ifr_addr.sa_len;
-#else
-#ifdef HAVE_STRUCT_IFMAP
   len = sizeof (struct ifmap);
-#else
-  len = sizeof (struct sockaddr);
-#endif
-#endif
 
   for (bufp = buf; bufp && *bufp && (bufp < (buf + ifc.ifc_len));
        bufp += sizeof (ifr->ifr_name) + len)
@@ -799,10 +790,6 @@ getinterfaces (int *howmany)
             ("You seem to have more than 1023 network interfaces. Things may not work right.\n");
           break;
         }
-#if HAVE_SOCKADDR_SA_LEN
-      /* len = MAX(sizeof(struct sockaddr), ifr->ifr_addr.sa_len); */
-      len = ifr->ifr_addr.sa_len;
-#endif
       mydevs[numinterfaces].name[0] = '\0';
     }
 
@@ -827,9 +814,9 @@ v6_getsourceip (struct in6_addr *src, struct in6_addr *dst)
 #endif
 
   if (IN6_IS_ADDR_V4MAPPED (dst))
-    *src = socket_get_next_source_v4_addr (NULL);
+    *src = socket_get_next_source_v4_addr ();
   else
-    *src = socket_get_next_source_v6_addr (NULL);
+    *src = socket_get_next_source_v6_addr ();
   if (!IN6_ARE_ADDR_EQUAL (src, &in6addr_any))
     {
       return 1;
@@ -928,7 +915,7 @@ getsourceip (struct in_addr *src, struct in_addr *dst)
   unsigned short p1;
 
 
-  *src = socket_get_next_source_addr (NULL);
+  *src = socket_get_next_source_addr ();
   if (src->s_addr != INADDR_ANY)
     {
       return 1;
@@ -991,7 +978,13 @@ getipv4routes (struct myroute *myroutes, int *numroutes)
     {
       /* OK, linux style /proc/net/route ... we can handle this ... */
       /* Now that we've got the interfaces, we g0 after the r0ut3Z */
-      fgets (buf, sizeof (buf), routez);        /* Kill the first line */
+      if (fgets (buf, sizeof (buf), routez) == NULL)  /* Kill the first line */
+        {
+          // /proc/net/route was empty or an error occurred.
+          printf ("Could not read from /proc/net/route");
+          fclose (routez);
+          return -1;
+        }
       while (fgets (buf, sizeof (buf), routez))
         {
           p = strtok (buf, " \t\n");
@@ -1218,9 +1211,9 @@ v6_routethrough (struct in6_addr *dest, struct in6_addr *source)
     printf ("ipaddr2devname passed a NULL dest address");
 
   if (IN6_IS_ADDR_V4MAPPED (dest))
-    src = socket_get_next_source_v4_addr (NULL);
+    src = socket_get_next_source_v4_addr ();
   else
-    src = socket_get_next_source_v6_addr (NULL);
+    src = socket_get_next_source_v6_addr ();
 
   if (!initialized)
     {
@@ -1401,7 +1394,7 @@ routethrough (struct in_addr *dest, struct in_addr *source)
   static int numroutes = 0;
   FILE *routez;
 
-  struct in_addr src = socket_get_next_source_addr (NULL);
+  struct in_addr src = socket_get_next_source_addr ();
 
   if (!dest)
     printf ("ipaddr2devname passed a NULL dest address");
@@ -1419,7 +1412,8 @@ routethrough (struct in_addr *dest, struct in_addr *source)
         {
           /* OK, linux style /proc/net/route ... we can handle this ... */
           /* Now that we've got the interfaces, we g0 after the r0ut3Z */
-          fgets (buf, sizeof (buf), routez);    /* Kill the first line */
+          if (fgets (buf, sizeof (buf), routez) == NULL)  /* Kill the first line */
+            printf ("Could not read from /proc/net/route");
           while (fgets (buf, sizeof (buf), routez))
             {
               p = strtok (buf, " \t\n");
