@@ -26,7 +26,9 @@
 #ifndef OPENVAS_PLUGUTILS_H
 #define OPENVAS_PLUGUTILS_H
 
-#include "arglists.h"
+#include "../misc/arglists.h"
+
+#include "../base/nvti.h"
 
 #define LEGACY_OID "1.3.6.1.4.1.25623.1.0."
 
@@ -36,6 +38,9 @@ void scanner_add_port (struct arglist *, int, char *);
 /*
  * Arglist management at plugin-level
  */
+void plug_set_nvti (struct arglist *, nvti_t *);
+nvti_t *plug_get_nvti (struct arglist *);
+
 void plug_set_name (struct arglist *, const char *);
 char *plug_get_name (struct arglist *);
 
