@@ -35,9 +35,9 @@
  * @return 0 on success, -1 on failure.
  */
 int
-host2ip (char * name, struct in_addr * ip)
+host2ip (char *name, struct in_addr *ip)
 {
-  struct hostent * ent;
+  struct hostent *ent;
 
   ent = gethostbyname (name);
   if (!ent)
@@ -45,7 +45,7 @@ host2ip (char * name, struct in_addr * ip)
   else if (ip)
     memcpy (ip, ent->h_addr, ent->h_length);
 
-  return 0; /* success */
+  return 0;                     /* success */
 }
 
 
@@ -54,31 +54,34 @@ nn_resolve (const char *hostname, struct in6_addr *in6addr)
 {
   struct addrinfo hints;
   struct addrinfo *ai;
-  int    retval;
+  int retval;
 
   *in6addr = in6addr_any;
-  /* first check whether it is a numeric host*/
-  memset(&hints, 0, sizeof(hints));
+  /* first check whether it is a numeric host */
+  memset (&hints, 0, sizeof (hints));
   hints.ai_family = AF_INET6;
   hints.ai_flags = AI_V4MAPPED | AI_ALL;
 
-  retval = getaddrinfo(hostname, NULL, &hints, &ai);
-  if(!retval)
-  {
-    if(ai->ai_family == AF_INET)
+  retval = getaddrinfo (hostname, NULL, &hints, &ai);
+  if (!retval)
     {
-      in6addr->s6_addr32[0] = 0;
-      in6addr->s6_addr32[1] = 0;
-      in6addr->s6_addr32[2] = htonl(0xffff);
-      memcpy(&in6addr->s6_addr32[3], &((struct sockaddr_in *)ai->ai_addr)->sin_addr, sizeof(struct in_addr));
-    }
-    else
-    {
-      memcpy(in6addr, &((struct sockaddr_in6 *)ai->ai_addr)->sin6_addr, sizeof(struct in6_addr));
-    }
+      if (ai->ai_family == AF_INET)
+        {
+          in6addr->s6_addr32[0] = 0;
+          in6addr->s6_addr32[1] = 0;
+          in6addr->s6_addr32[2] = htonl (0xffff);
+          memcpy (&in6addr->s6_addr32[3],
+                  &((struct sockaddr_in *) ai->ai_addr)->sin_addr,
+                  sizeof (struct in_addr));
+        }
+      else
+        {
+          memcpy (in6addr, &((struct sockaddr_in6 *) ai->ai_addr)->sin6_addr,
+                  sizeof (struct in6_addr));
+        }
 
-    freeaddrinfo(ai);
-    return 0;
-  }
+      freeaddrinfo (ai);
+      return 0;
+    }
   return -1;
 }
