@@ -113,7 +113,7 @@
 
 #include <glib.h>
 
-#include "arglists.h"           /* for struct arglist */
+#include "../misc/arglists.h"           /* for struct arglist */
 
 /* Signature information extraction and verification (not nasl- specific 
   anymore, thus likely to be moved to openvas-libraries): */
