@@ -20,7 +20,7 @@
 #include <stdarg.h>
 #include <unistd.h>
 
-#include "arglists.h"
+#include "../misc/arglists.h"
 
 #include "nasl_tree.h"
 #include "nasl_global_ctxt.h"
