@@ -1,4 +1,4 @@
-/* Nessus Attack Scripting Language 
+/* Nessus Attack Scripting Language
  *
  * Copyright (C) 2002 - 2004 Tenable Network Security
  *
@@ -17,24 +17,23 @@
  *
  */
 
-#include <string.h>             /* for memset */
+#include "nasl_raw.h"       /* to e.g. favour BSD, but also for IPPROTO_TCP
+                               and TH_FIN */
 
-#include "nvt_categories.h"     /* for ACT_INIT */
-#include "plugutils.h"          /* for OPENVAS_ENCAPS_IP */
+#include <string.h>         /* for memset */
+
+#include "nvt_categories.h" /* for ACT_INIT */
+#include "plugutils.h"      /* for OPENVAS_ENCAPS_IP */
 
-#include "nasl_tcp.h"
 #include "nasl.h"
-
 #include "nasl_tree.h"
 #include "nasl_global_ctxt.h"
 #include "nasl_func.h"
 #include "nasl_var.h"
 #include "nasl_lex_ctxt.h"
 #include "exec.h"
-
 #include "nasl_packet_forgery.h"
 #include "nasl_debug.h"
-
 #include "nasl_socket.h"
 #include "nasl_http.h"
 #include "nasl_host.h"
@@ -47,6 +46,7 @@
 #include "nasl_wmi.h"
 #include "nasl_smb.h"
 #include "nasl_packet_forgery_v6.h"
+#include "nasl_builtin_plugins.h"
 
 /* **************************************************************** */
 
@@ -382,14 +382,14 @@ static init_func libfuncs[] = {
 
   {"wmi_versioninfo", nasl_wmi_versioninfo, 0, {NULL}},
   {"wmi_connect", nasl_wmi_connect, 4,
-   {"host", "ns", "password", "username", NULL}},
+   {"ns", "password", "username", NULL}},
   {"wmi_close", nasl_wmi_close, 0, {"wmi_handle", NULL}},
   {"wmi_query", nasl_wmi_query, 0, {"query", "wmi_handle", NULL}},
   {"wmi_connect_rsop", nasl_wmi_connect_rsop, 0,
-   {"host", "password", "username", NULL}},
+   {"password", "username", NULL}},
   {"wmi_query_rsop", nasl_wmi_query_rsop, 0, {"query", "wmi_handle", NULL}},
   {"wmi_connect_reg", nasl_wmi_connect_reg, 0,
-   {"host", "password", "username", NULL}},
+   {"password", "username", NULL}},
   {"wmi_reg_enum_key", nasl_wmi_reg_enum_key, 0,
    {"hive", "key", "wmi_handle", NULL}},
   {"wmi_reg_enum_value", nasl_wmi_reg_enum_value, 0,
@@ -409,7 +409,7 @@ static init_func libfuncs[] = {
 
   {"smb_versioninfo", nasl_smb_versioninfo, 0, {NULL}},
   {"smb_connect", nasl_smb_connect, 0,
-   {"host", "password", "share", "username", NULL}},
+   {"password", "share", "username", NULL}},
   {"smb_close", nasl_smb_close, 0, {"smb_handle", NULL}},
   {"smb_file_SDDL", nasl_smb_file_SDDL, 0, {"filename", "smb_handle", NULL}},
   {"smb_file_owner_sid", nasl_smb_file_owner_sid, 0,
@@ -419,6 +419,13 @@ static init_func libfuncs[] = {
   {"smb_file_trustee_rights", nasl_smb_file_trustee_rights, 0,
    {"filename", "smb_handle", NULL}},
 
+  {"scan_phase", scan_phase, 0, {NULL}},
+  {"network_targets", network_targets, 0, {NULL}},
+
+  {"plugin_run_find_service", plugin_run_find_service, 0, {NULL}},
+  {"plugin_run_openvas_tcp_scanner", plugin_run_openvas_tcp_scanner, 0, {NULL}},
+  {"plugin_run_synscan", plugin_run_synscan, 0, {NULL}},
+
   {NULL, NULL, 0, {NULL}}
 };
 
@@ -430,7 +437,7 @@ static struct
 } libsvars[] =
 {
   {
-  "OPENVAS_VERSION", VERSION},
+  "OPENVAS_VERSION", OPENVASLIB_VERSION},
   {
 NULL, NULL},};
 
@@ -615,8 +622,8 @@ init_nasl_library (lex_ctxt * lexic)
 char *
 nasl_version ()
 {
-  static char vers[sizeof (VERSION) + 1];
-  strncpy (vers, VERSION, sizeof (vers) - 1);   /* Flawfinder: ignore
+  static char vers[sizeof (OPENVASLIB_VERSION) + 1];
+  strncpy (vers, OPENVASLIB_VERSION, sizeof (vers) - 1);   /* Flawfinder: ignore
                                                    (\0-termination taken care of) */
   vers[sizeof (vers) - 1] = '\0';
   return vers;
