@@ -45,7 +45,11 @@
 
 #include <string.h>
 #include <stdio.h>
+#include <netinet/in.h>
+#include <sys/socket.h>
+#include <arpa/inet.h>
 #include "system.h"
+#include "plugutils.h"
 
 #include "nasl_wmi.h"
 #include "openvas_wmi_interface.h"
@@ -103,7 +107,10 @@ nasl_wmi_versioninfo (lex_ctxt * lexic)
 tree_cell *
 nasl_wmi_connect (lex_ctxt * lexic)
 {
-  IMPORT (host);
+  struct arglist *script_infos = lexic->script_infos;
+  struct in6_addr *host = plug_get_host_ip (script_infos);
+  char *ip;
+  char name[512];
   IMPORT (username);
   IMPORT (password);
   IMPORT(ns);
@@ -124,8 +131,19 @@ nasl_wmi_connect (lex_ctxt * lexic)
       return NULL;
     }
 
+  if (IN6_IS_ADDR_V4MAPPED (host))
+    {
+      struct in_addr v4_addr;
+      v4_addr.s_addr = host->s6_addr32[3];
+      ip = estrdup (inet_ntoa (v4_addr));
+    }
+  else
+    {
+      ip = estrdup (inet_ntop (AF_INET6, host, name, sizeof (name)));
+    }
+
   if ((strlen (password) == 0) || (strlen (username) == 0)
-      || strlen (host) == 0)
+        || strlen (ip) == 0)
     {
       fprintf (stderr, "nasl_wmi_connect: Invalid input arguments\n");
       return NULL;
@@ -134,7 +152,7 @@ nasl_wmi_connect (lex_ctxt * lexic)
   argv[0] = (char *) emalloc (strlen (argv1));
   argv[1] = (char *) emalloc (strlen (argv2));
   argv[2] = (char *) emalloc (strlen (username) + strlen (password) + 1);
-  argv[3] = (char *) emalloc (strlen (host) + 2);
+  argv[3] = (char *) emalloc (strlen (ip) + 2);
   argv[4] = (char *) emalloc (strlen (ns));
 
   // Construct the WMI query
@@ -144,7 +162,7 @@ nasl_wmi_connect (lex_ctxt * lexic)
   strcat (argv[2], "%");
   strcat (argv[2], password);
   strcpy (argv[3], "//");
-  strcat (argv[3], host);
+  strcat (argv[3], ip);
   strcpy (argv[4], ns);
 
   tree_cell *retc = alloc_tree_cell (0, NULL);
@@ -263,7 +281,10 @@ nasl_wmi_query (lex_ctxt * lexic)
 tree_cell *
 nasl_wmi_connect_rsop (lex_ctxt * lexic)
 {
-  IMPORT (host);
+  struct arglist *script_infos = lexic->script_infos;
+  struct in6_addr *host = plug_get_host_ip (script_infos);
+  char *ip;
+  char name[512];
   IMPORT (username);
   IMPORT (password);
   char *argv[4];
@@ -279,8 +300,19 @@ nasl_wmi_connect_rsop (lex_ctxt * lexic)
       return NULL;
     }
 
+  if (IN6_IS_ADDR_V4MAPPED (host))
+    {
+      struct in_addr v4_addr;
+      v4_addr.s_addr = host->s6_addr32[3];
+      ip = estrdup (inet_ntoa (v4_addr));
+    }
+  else
+    {
+      ip = estrdup (inet_ntop (AF_INET6, host, name, sizeof (name)));
+    }
+
   if ((strlen (password) == 0) || (strlen (username) == 0)
-      || strlen (host) == 0)
+      || strlen (ip) == 0)
     {
       fprintf (stderr, "nasl_wmi_connect_rsop: Invalid input arguments\n");
       return NULL;
@@ -289,7 +321,7 @@ nasl_wmi_connect_rsop (lex_ctxt * lexic)
   argv[0] = (char *) emalloc (strlen (argv1));
   argv[1] = (char *) emalloc (strlen (argv2));
   argv[2] = (char *) emalloc (strlen (username) + strlen (password) + 1);
-  argv[3] = (char *) emalloc (strlen (host) + 2);
+  argv[3] = (char *) emalloc (strlen (ip) + 2);
 
   // Construct the WMI query
   strcpy (argv[0], argv1);
@@ -298,7 +330,7 @@ nasl_wmi_connect_rsop (lex_ctxt * lexic)
   strcat (argv[2], "%");
   strcat (argv[2], password);
   strcpy (argv[3], "//");
-  strcat (argv[3], host);
+  strcat (argv[3], ip);
 
   tree_cell *retc = alloc_tree_cell (0, NULL);
   if (!retc)
@@ -379,7 +411,10 @@ nasl_wmi_query_rsop (lex_ctxt * lexic)
 tree_cell *
 nasl_wmi_connect_reg (lex_ctxt * lexic)
 {
-  IMPORT (host);
+  struct arglist *script_infos = lexic->script_infos;
+  struct in6_addr *host = plug_get_host_ip (script_infos);
+  char *ip;
+  char name[512];
   IMPORT (username);
   IMPORT (password);
   char *argv[4];
@@ -395,8 +430,19 @@ nasl_wmi_connect_reg (lex_ctxt * lexic)
       return NULL;
     }
 
+  if (IN6_IS_ADDR_V4MAPPED (host))
+    {
+      struct in_addr v4_addr;
+      v4_addr.s_addr = host->s6_addr32[3];
+      ip = estrdup (inet_ntoa (v4_addr));
+    }
+  else
+    {
+      ip = estrdup (inet_ntop (AF_INET6, host, name, sizeof (name)));
+    }
+
   if ((strlen (password) == 0) || (strlen (username) == 0)
-      || strlen (host) == 0)
+      || strlen (ip) == 0)
     {
       fprintf (stderr, "nasl_wmi_connect_reg: Invalid input arguments\n");
       return NULL;
@@ -405,7 +451,7 @@ nasl_wmi_connect_reg (lex_ctxt * lexic)
   argv[0] = (char *) emalloc (strlen (argv1));
   argv[1] = (char *) emalloc (strlen (argv2));
   argv[2] = (char *) emalloc (strlen (username) + strlen (password) + 1);
-  argv[3] = (char *) emalloc (strlen (host) + 2);
+  argv[3] = (char *) emalloc (strlen (ip) + 2);
 
   // Construct the WMI query
   strcpy (argv[0], argv1);
@@ -414,7 +460,7 @@ nasl_wmi_connect_reg (lex_ctxt * lexic)
   strcat (argv[2], "%");
   strcat (argv[2], password);
   strcpy (argv[3], "//");
-  strcat (argv[3], host);
+  strcat (argv[3], ip);
 
   tree_cell *retc = alloc_tree_cell (0, NULL);
   if (!retc)
