@@ -119,6 +119,62 @@ omp_task_status (entity_t response)
   return NULL;
 }
 
+/**
+ * @brief "Ping" the manager.
+ *
+ * @param[in]  session   Pointer to GNUTLS session.
+ * @param[in]  timeout   Server idle time before giving up, in milliseconds.  0
+ *                       to wait forever.
+ *
+ * @return 0 on success, 1 if manager closed connection, 2 on timeout,
+ *         -1 on error.
+ */
+int
+omp_ping (gnutls_session_t *session, int timeout)
+{
+  entity_t entity;
+  const char* status;
+  char first;
+  int ret;
+
+  /* Send a GET_VERSION request. */
+
+  ret = openvas_server_send (session, "<get_version/>");
+  if (ret)
+    return ret;
+
+  /* Read the response, with a timeout. */
+
+  entity = NULL;
+  switch (try_read_entity (session, timeout, &entity))
+    {
+      case 0:
+        break;
+      case -4:
+        return 2;
+      default:
+        return -1;
+    }
+
+  /* Check the response. */
+
+  status = entity_attribute (entity, "status");
+  if (status == NULL)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  if (strlen (status) == 0)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  first = status[0];
+  free_entity (entity);
+  if (first == '2') return 0;
+  return -1;
+}
+
 /**
  * @brief Authenticate with the manager.
  *
@@ -141,12 +197,12 @@ omp_authenticate (gnutls_session_t* session,
 
   /* Send the auth request. */
 
-  msg = g_strdup_printf ("<authenticate><credentials>"
-                         "<username>%s</username>"
-                         "<password>%s</password>"
-                         "</credentials></authenticate>",
-                         username,
-                         password);
+  msg = g_markup_printf_escaped ("<authenticate><credentials>"
+                                 "<username>%s</username>"
+                                 "<password>%s</password>"
+                                 "</credentials></authenticate>",
+                                 username,
+                                 password);
   int ret = openvas_server_send (session, msg);
   g_free (msg);
   if (ret) return ret;
@@ -212,7 +268,7 @@ omp_authenticate_env (gnutls_session_t* session)
  * @param[out]  id          Pointer for newly allocated ID of new task.  Only
  *                          set on successful return.
  *
- * @return 0 on success, -1 on error.
+ * @return 0 on success, -1 or OMP response code on error.
  */
 int
 omp_create_task (gnutls_session_t* session,
@@ -225,16 +281,16 @@ omp_create_task (gnutls_session_t* session,
   /* Create the OMP request. */
 
   gchar* new_task_request;
-  new_task_request = g_strdup_printf ("<create_task>"
-                                      "<config>%s</config>"
-                                      "<target>%s</target>"
-                                      "<name>%s</name>"
-                                      "<comment>%s</comment>"
-                                      "</create_task>",
-                                      config,
-                                      target,
-                                      name,
-                                      comment);
+  new_task_request = g_markup_printf_escaped ("<create_task>"
+                                              "<config id=\"%s\"/>"
+                                              "<target id=\"%s\"/>"
+                                              "<name>%s</name>"
+                                              "<comment>%s</comment>"
+                                              "</create_task>",
+                                              config,
+                                              target,
+                                              name,
+                                              comment);
 
   /* Send the request. */
 
@@ -244,19 +300,10 @@ omp_create_task (gnutls_session_t* session,
 
   /* Read the response. */
 
-  entity_t entity = NULL;
-  if (read_entity (session, &entity)) return -1;
-
-  /* Get the ID of the new task from the response. */
-
-  entity_t id_entity = entity_child (entity, "task_id");
-  if (id_entity == NULL)
-    {
-      free_entity (entity);
-      return -1;
-    }
-  *id = g_strdup (entity_text (id_entity));
-  return 0;
+  ret = omp_read_create_response (session, id);
+  if (ret == 201)
+    return 0;
+  return ret;
 }
 
 /**
@@ -289,14 +336,14 @@ omp_create_task_rc (gnutls_session_t* session,
   /* Create the OMP request. */
 
   gchar* new_task_request;
-  new_task_request = g_strdup_printf ("<create_task>"
-                                      "<rcfile>%s</rcfile>"
-                                      "<name>%s</name>"
-                                      "<comment>%s</comment>"
-                                      "</create_task>",
-                                      new_task_file,
-                                      name,
-                                      comment);
+  new_task_request = g_markup_printf_escaped ("<create_task>"
+                                              "<rcfile>%s</rcfile>"
+                                              "<name>%s</name>"
+                                              "<comment>%s</comment>"
+                                              "</create_task>",
+                                              new_task_file,
+                                              name,
+                                              comment);
   g_free (new_task_file);
 
   /* Send the request. */
@@ -373,7 +420,7 @@ omp_create_task_rc_file (gnutls_session_t* session,
  * @param[in]   task_id    ID of task.
  * @param[out]  report_id  ID of report.
  *
- * @return 0 on success, -1 on error.
+ * @return 0 on success, 1 on failure, -1 on error.
  */
 int
 omp_start_task_report (gnutls_session_t* session, const char* task_id,
@@ -421,7 +468,7 @@ omp_start_task_report (gnutls_session_t* session, const char* task_id,
       return 0;
     }
   free_entity (entity);
-  return -1;
+  return 1;
 }
 
 /**
@@ -430,7 +477,7 @@ omp_start_task_report (gnutls_session_t* session, const char* task_id,
  * @param[in]   session    Pointer to GNUTLS session.
  * @param[in]   task_id    ID of task.
  *
- * @return 0 on success, -1 on error.
+ * @return 0 on success, 1 on failure, -1 on error.
  */
 int
 omp_start_task (gnutls_session_t* session, const char* task_id)
@@ -445,7 +492,7 @@ omp_start_task (gnutls_session_t* session, const char* task_id)
  * @param[in]   task_id    ID of task.
  * @param[out]  report_id  ID of report.
  *
- * @return 0 on success, -1 on error.
+ * @return 0 on success, 1 on failure, -1 on error.
  */
 int
 omp_resume_or_start_task_report (gnutls_session_t* session, const char* task_id,
@@ -493,7 +540,7 @@ omp_resume_or_start_task_report (gnutls_session_t* session, const char* task_id,
       return 0;
     }
   free_entity (entity);
-  return -1;
+  return 1;
 }
 
 /**
@@ -502,7 +549,7 @@ omp_resume_or_start_task_report (gnutls_session_t* session, const char* task_id,
  * @param[in]   session    Pointer to GNUTLS session.
  * @param[in]   task_id    ID of task.
  *
- * @return 0 on success, -1 on error.
+ * @return 0 on success, 1 on failure, -1 on error.
  */
 int
 omp_resume_or_start_task (gnutls_session_t* session, const char* task_id)
@@ -549,6 +596,61 @@ check_response (gnutls_session_t* session)
   return 1;
 }
 
+/**
+ * @brief Read response status and resource UUID.
+ *
+ * @param[in]  session  Pointer to GNUTLS session.
+ * @param[out] uuid     Either NULL or address for freshly allocated UUID of
+ *                      created response.
+ *
+ * @return OMP response code on success, -1 on error.
+ */
+int
+omp_read_create_response (gnutls_session_t* session, char **uuid)
+{
+  int ret;
+  const char *status, *id;
+  entity_t entity;
+
+  /* Read the response. */
+
+  entity = NULL;
+  if (read_entity (session, &entity)) return -1;
+
+  /* Parse the response. */
+
+  status = entity_attribute (entity, "status");
+  if (status == NULL)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  if (strlen (status) == 0)
+    {
+      free_entity (entity);
+      return -1;
+    }
+
+  if (uuid)
+    {
+      id = entity_attribute (entity, "id");
+      if (id == NULL)
+        {
+          free_entity (entity);
+          return -1;
+        }
+      if (strlen (id) == 0)
+        {
+          free_entity (entity);
+          return -1;
+        }
+      *uuid = g_strdup (id);
+    }
+
+  ret = atoi (status);
+  free_entity (entity);
+  return ret;
+}
 
 /**
  * @brief Deprecated wrapper function for /ref omp_stop_task.
@@ -586,6 +688,123 @@ omp_stop_task (gnutls_session_t* session, const char* id)
   return check_response (session);
 }
 
+/**
+ * @brief Pause a task and read the manager response.
+ *
+ * @param[in]   session    Pointer to GNUTLS session.
+ * @param[in]   task_id    ID of task.
+ *
+ * @return 0 on success, 1 on OMP failure, -1 on error.
+ */
+int
+omp_pause_task (gnutls_session_t* session, const char* task_id)
+{
+  if (openvas_server_sendf (session,
+                            "<pause_task task_id=\"%s\"/>",
+                            task_id)
+      == -1)
+    return -1;
+
+  return check_response (session);
+}
+
+/**
+ * @brief Resume a paused task and read the manager response.
+ *
+ * @param[in]   session    Pointer to GNUTLS session.
+ * @param[in]   task_id    ID of task.
+ *
+ * @return 0 on success, 1 on OMP failure, -1 on error.
+ */
+int
+omp_resume_paused_task (gnutls_session_t* session, const char* task_id)
+{
+  if (openvas_server_sendf (session,
+                            "<resume_paused_task task_id=\"%s\"/>",
+                            task_id)
+      == -1)
+    return -1;
+
+  return check_response (session);
+}
+
+/**
+ * @brief Resume a stopped task and read the manager response.
+ *
+ * @param[in]   session    Pointer to GNUTLS session.
+ * @param[in]   task_id    ID of task.
+ *
+ * @return 0 on success, 1 on OMP failure, -1 on error.
+ */
+int
+omp_resume_stopped_task (gnutls_session_t* session, const char* task_id)
+{
+  if (openvas_server_sendf (session,
+                            "<resume_stopped_task task_id=\"%s\"/>",
+                            task_id)
+      == -1)
+    return -1;
+
+  return check_response (session);
+}
+
+/**
+ * @brief Resume a stopped task and read the manager response.
+ *
+ * @param[in]   session    Pointer to GNUTLS session.
+ * @param[in]   task_id    ID of task.
+ * @param[out]  report_id  ID of report.
+ *
+ * @return 0 on success, 1 on OMP failure, -1 on error.
+ */
+int
+omp_resume_stopped_task_report (gnutls_session_t* session, const char* task_id,
+                                char** report_id)
+{
+  if (openvas_server_sendf (session,
+                            "<resume_stopped_task task_id=\"%s\"/>",
+                            task_id)
+      == -1)
+    return -1;
+
+  /* Read the response. */
+
+  entity_t entity = NULL;
+  if (read_entity (session, &entity)) return -1;
+
+  /* Check the response. */
+
+  const char* status = entity_attribute (entity, "status");
+  if (status == NULL)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  if (strlen (status) == 0)
+    {
+      free_entity (entity);
+      return -1;
+    }
+  char first = status[0];
+  if (first == '2')
+    {
+      if (report_id)
+        {
+          entity_t report_id_xml = entity_child (entity, "report_id");
+          if (report_id_xml)
+            *report_id = g_strdup (entity_text (report_id_xml));
+          else
+            {
+              free_entity (entity);
+              return -1;
+            }
+        }
+      free_entity (entity);
+      return 0;
+    }
+  free_entity (entity);
+  return 1;
+}
 
 /**
  * @brief Issue \ref command against the server in \ref session, waits for
@@ -667,21 +886,6 @@ omp_get_nvt_feed_checksum (gnutls_session_t* session, entity_t* response)
 }
 
 
-/**
- * @brief Issue an OMP \<get_rules\/\> command and wait for the response.
- *
- * @param[in]  session   Session to the server.
- * @param[out] response  Entity containing the response, must be freed.
- *
- * @return 0 in case of success. -1 otherwise (e.g. invalid session).
- */
-int
-omp_get_rules_503 (gnutls_session_t* session, entity_t* response)
-{
-  return get_omp_response_503 (session, "<get_rules/>", response);
-}
-
-
 /**
  * @brief Issue an OMP \<get_dependencies/\> command and wait for the response.
  *
@@ -1044,8 +1248,12 @@ omp_wait_for_task_delete (gnutls_session_t* session,
       if (read_entity (session, &entity)) return -1;
 
       status = omp_task_status (entity);
+      if (status == NULL)
+        {
+          free_entity (entity);
+          break;
+        }
       free_entity (entity);
-      if (status == NULL) break;
 
       sleep (1);
     }
@@ -1159,6 +1367,69 @@ omp_get_tasks (gnutls_session_t* session, const char* id, int details,
   return ret;
 }
 
+/**
+ * @brief Get a target.
+ *
+ * @param[in]  session         Pointer to GNUTLS session.
+ * @param[in]  id              ID of target or NULL for all targets.
+ * @param[in]  tasks           Whether to include tasks that use the target.
+ * @param[out] target          Target return.  On success contains GET_TARGETS
+ *                             response.
+ *
+ * @return 0 on success, -1 or OMP response code on error.
+ */
+int
+omp_get_targets (gnutls_session_t* session, const char* id, int tasks,
+                 int include_rcfile, entity_t* target)
+{
+  const char* status_code;
+  int ret;
+
+  if (id == NULL)
+    {
+      if (openvas_server_sendf (session,
+                                "<get_targets tasks=\"%i\"/>",
+                                tasks)
+          == -1)
+        return -1;
+    }
+  else
+    {
+      if (openvas_server_sendf (session,
+                                "<get_targets"
+                                " target_id=\"%s\""
+                                " tasks=\"%i\"/>",
+                                id,
+                                tasks)
+          == -1)
+        return -1;
+    }
+
+  /* Read the response. */
+
+  *target = NULL;
+  if (read_entity (session, target)) return -1;
+
+  /* Check the response. */
+
+  status_code = entity_attribute (*target, "status");
+  if (status_code == NULL)
+    {
+      free_entity (*target);
+      return -1;
+    }
+  if (strlen (status_code) == 0)
+    {
+      free_entity (*target);
+      return -1;
+    }
+  if (status_code[0] == '2') return 0;
+  ret = (int) strtol (status_code, NULL, 10);
+  free_entity (*target);
+  if (errno == ERANGE) return -1;
+  return ret;
+}
+
 /**
  * @brief Get a report.
  *
@@ -1172,17 +1443,19 @@ int
 omp_get_report (gnutls_session_t* session,
                 const char* id,
                 const char* format,
+                int first_result_number,
                 entity_t* response)
 {
   if (openvas_server_sendf (session,
-                            /** @todo Enable after 3.2 release, so that 3.2
-                              *       remains compatible with Manager 1.0. */
-#if 0
-                            "<get_reports format_id=\"%s\" report_id=\"%s\"/>",
-#else
-                            "<get_reports format=\"%s\" report_id=\"%s\"/>",
-#endif
-                            format ? format : "nbe",
+                            "<get_reports"
+                            " result_hosts_only=\"0\""
+                            " first_result=\"%i\""
+                            " sort_field=\"ROWID\""
+                            " sort_order=\"1\""
+                            " format_id=\"%s\""
+                            " report_id=\"%s\"/>",
+                            first_result_number,
+                            format ? format : "XML",
                             id))
     return -1;
 
@@ -1219,13 +1492,7 @@ omp_get_report_format (gnutls_session_t* session,
   entity_t entity;
 
   if (openvas_server_sendf (session,
-                            /** @todo Enable after 3.2 release, so that 3.2
-                              *       remains compatible with Manager 1.0. */
-#if 0
                             "<get_reports format_id=\"%s\" report_id=\"%s\"/>",
-#else
-                            "<get_reports format=\"%s\" report_id=\"%s\"/>",
-#endif
                             format,
                             id))
     return -1;
@@ -1296,6 +1563,83 @@ omp_delete_report (gnutls_session_t* session, const char* id)
   return check_response (session);
 }
 
+/**
+ * @brief Get results.
+ *
+ * @param[in]  session            Pointer to GNUTLS session.
+ * @param[in]  task_id            ID of task whose to get, NULL for all.
+ * @param[in]  notes              Whether to include notes.
+ * @param[in]  notes_details      If notes, whether to include details.
+ * @param[in]  overrides          Whether to include notes.
+ * @param[in]  overrides_details  If overrides, whether to include details.
+ * @param[in]  apply_overrides    Whether to apply overrides.
+ * @param[out] response           On success contains the GET_RESULTS response.
+ *
+ * @return 0 on success, -1 or OMP response code on error.
+ */
+int
+omp_get_results (gnutls_session_t* session,
+                 const char* task_id,
+                 int notes,
+                 int notes_details,
+                 int overrides,
+                 int overrides_details,
+                 int apply_overrides,
+                 entity_t* response)
+{
+  if (openvas_server_sendf (session,
+                            "<get_results"
+                            "%s%s%s"
+                            " notes=\"%i\""
+                            " notes_details=\"%i\""
+                            " overrides=\"%i\""
+                            " overrides_details=\"%i\""
+                            " apply_overrides=\"%i\"/>",
+                            task_id ? " task_id=\"" : "",
+                            task_id ? task_id : "",
+                            task_id ? "\"" : "",
+                            notes,
+                            notes_details,
+                            overrides,
+                            overrides_details,
+                            apply_overrides))
+    return -1;
+
+  {
+    const char* status;
+    entity_t entity;
+
+    /* Read the response. */
+
+    entity = NULL;
+    if (read_entity (session, &entity)) return -1;
+
+    /* Check the response. */
+
+    status = entity_attribute (entity, "status");
+    if (status == NULL)
+      {
+        free_entity (entity);
+        return -1;
+      }
+    if (strlen (status) == 0)
+      {
+        free_entity (entity);
+        return -1;
+      }
+    if (status[0] == '2')
+      {
+        if (response)
+          *response = entity;
+        else
+          free_entity (entity);
+        return 0;
+      }
+    free_entity (entity);
+    return 1;
+  }
+}
+
 /**
  * @brief Modify a task.
  *
@@ -1506,22 +1850,66 @@ omp_until_up (int (*function) (gnutls_session_t*, entity_t*),
  * @param[in]   name        Name of target.
  * @param[in]   hosts       Target hosts.
  * @param[in]   comment     Target comment.
+ * @param[in]   ssh_credential  UUID of SSH LSC credential.
+ * @param[in]   smb_credential  UUID of SMB LSC credential.
+ * @param[out]  uuid        Either NULL or address for UUID of created target.
  *
- * @return 0 on success, -1 on error.
+ * @return 0 on success, -1 or OMP response code on error.
  */
 int
 omp_create_target (gnutls_session_t* session,
                    const char* name,
                    const char* hosts,
-                   const char* comment)
+                   const char* comment,
+                   const char* ssh_credential,
+                   const char* smb_credential,
+                   char** uuid)
 {
   int ret;
 
-  /* Create the OMP request. */
-
-  gchar* new_task_request;
   if (comment)
-    new_task_request = g_strdup_printf ("<create_target>"
+    {
+      if (ssh_credential && smb_credential)
+        ret = openvas_server_sendf_xml (session,
+                                        "<create_target>"
+                                        "<name>%s</name>"
+                                        "<hosts>%s</hosts>"
+                                        "<comment>%s</comment>"
+                                        "<ssh_lsc_credential id=\"%s\"/>"
+                                        "<smb_lsc_credential id=\"%s\"/>"
+                                        "</create_target>",
+                                        name,
+                                        hosts,
+                                        comment,
+                                        ssh_credential,
+                                        smb_credential);
+      else if (ssh_credential)
+        ret = openvas_server_sendf_xml (session,
+                                        "<create_target>"
+                                        "<name>%s</name>"
+                                        "<hosts>%s</hosts>"
+                                        "<comment>%s</comment>"
+                                        "<ssh_lsc_credential id=\"%s\"/>"
+                                        "</create_target>",
+                                        name,
+                                        hosts,
+                                        comment,
+                                        ssh_credential);
+      else if (smb_credential)
+        ret = openvas_server_sendf_xml (session,
+                                        "<create_target>"
+                                        "<name>%s</name>"
+                                        "<hosts>%s</hosts>"
+                                        "<comment>%s</comment>"
+                                        "<smb_lsc_credential id=\"%s\"/>"
+                                        "</create_target>",
+                                        name,
+                                        hosts,
+                                        comment,
+                                        smb_credential);
+      else
+        ret = openvas_server_sendf_xml (session,
+                                        "<create_target>"
                                         "<name>%s</name>"
                                         "<hosts>%s</hosts>"
                                         "<comment>%s</comment>"
@@ -1529,50 +1917,76 @@ omp_create_target (gnutls_session_t* session,
                                         name,
                                         hosts,
                                         comment);
+    }
   else
-    new_task_request = g_strdup_printf ("<create_target>"
+    {
+      if (ssh_credential && smb_credential)
+        ret = openvas_server_sendf_xml (session,
+                                        "<create_target>"
+                                        "<name>%s</name>"
+                                        "<hosts>%s</hosts>"
+                                        "<ssh_lsc_credential id=\"%s\"/>"
+                                        "<smb_lsc_credential id=\"%s\"/>"
+                                        "</create_target>",
+                                        name,
+                                        hosts,
+                                        ssh_credential,
+                                        smb_credential);
+      else if (ssh_credential)
+        ret = openvas_server_sendf_xml (session,
+                                        "<create_target>"
+                                        "<name>%s</name>"
+                                        "<hosts>%s</hosts>"
+                                        "<ssh_lsc_credential id=\"%s\"/>"
+                                        "</create_target>",
+                                        name,
+                                        hosts,
+                                        ssh_credential);
+      else if (smb_credential)
+        ret = openvas_server_sendf_xml (session,
+                                        "<create_target>"
+                                        "<name>%s</name>"
+                                        "<hosts>%s</hosts>"
+                                        "<ssh_lsc_credential id=\"%s\"/>"
+                                        "</create_target>",
+                                        name,
+                                        hosts,
+                                        smb_credential);
+      else
+        ret = openvas_server_sendf_xml (session,
+                                        "<create_target>"
                                         "<name>%s</name>"
                                         "<hosts>%s</hosts>"
                                         "</create_target>",
                                         name,
                                         hosts);
+    }
 
-  /* Send the request. */
-
-  ret = openvas_server_send (session, new_task_request);
-  g_free (new_task_request);
   if (ret) return -1;
 
-  return check_response (session);
+  ret = omp_read_create_response (session, uuid);
+  if (ret == 201)
+    return 0;
+  return ret;
 }
 
 /**
  * @brief Delete a target.
  *
  * @param[in]   session     Pointer to GNUTLS session.
- * @param[in]   name        Name of target.
+ * @param[in]   id          UUID of target.
  *
  * @return 0 on success, -1 on error.
  */
 int
 omp_delete_target (gnutls_session_t* session,
-                   const char* name)
+                   const char* id)
 {
-  int ret;
-
-  /* Create the OMP request. */
-
-  gchar* new_task_request;
-  new_task_request = g_strdup_printf ("<delete_target>"
-                                      "<name>%s</name>"
-                                      "</delete_target>",
-                                      name);
-
-  /* Send the request. */
-
-  ret = openvas_server_send (session, new_task_request);
-  g_free (new_task_request);
-  if (ret) return -1;
+  if (openvas_server_sendf (session,
+                            "<delete_target target_id=\"%s\"/>",
+                            id)
+      == -1)
+    return -1;
 
   return check_response (session);
 }
@@ -1605,21 +2019,21 @@ omp_create_config (gnutls_session_t* session,
 
   gchar* new_config_request;
   if (comment)
-    new_config_request = g_strdup_printf ("<create_config>"
-                                          "<name>%s</name>"
-                                          "<comment>%s</comment>"
-                                          "<rcfile>%s</rcfile>"
-                                          "</create_config>",
-                                          name,
-                                          comment,
-                                          new_config_file);
+    new_config_request = g_markup_printf_escaped ("<create_config>"
+                                                  "<name>%s</name>"
+                                                  "<comment>%s</comment>"
+                                                  "<rcfile>%s</rcfile>"
+                                                  "</create_config>",
+                                                  name,
+                                                  comment,
+                                                  new_config_file);
   else
-    new_config_request = g_strdup_printf ("<create_config>"
-                                          "<name>%s</name>"
-                                          "<rcfile>%s</rcfile>"
-                                          "</create_config>",
-                                          name,
-                                          new_config_file);
+    new_config_request = g_markup_printf_escaped ("<create_config>"
+                                                  "<name>%s</name>"
+                                                  "<rcfile>%s</rcfile>"
+                                                  "</create_config>",
+                                                  name,
+                                                  new_config_file);
   g_free (new_config_file);
 
   /* Send the request. */
@@ -1677,29 +2091,19 @@ omp_create_config_from_rc_file (gnutls_session_t* session,
  * @brief Delete a config.
  *
  * @param[in]   session     Pointer to GNUTLS session.
- * @param[in]   name        Name of config.
+ * @param[in]   id          UUID of config.
  *
  * @return 0 on success, -1 on error.
  */
 int
 omp_delete_config (gnutls_session_t* session,
-                   const char* name)
+                   const char* id)
 {
-  int ret;
-
-  /* Create the OMP request. */
-
-  gchar* new_task_request;
-  new_task_request = g_strdup_printf ("<delete_config>"
-                                      "<name>%s</name>"
-                                      "</delete_config>",
-                                      name);
-
-  /* Send the request. */
-
-  ret = openvas_server_send (session, new_task_request);
-  g_free (new_task_request);
-  if (ret) return -1;
+  if (openvas_server_sendf (session,
+                            "<delete_config config_id=\"%s\"/>",
+                            id)
+      == -1)
+    return -1;
 
   return check_response (session);
 }
@@ -1707,40 +2111,70 @@ omp_delete_config (gnutls_session_t* session,
 /**
  * @brief Create an LSC Credential.
  *
- * @param[in]   session  Pointer to GNUTLS session.
- * @param[in]   name     Name of LSC Credential.
- * @param[in]   login    Login associated with name.
- * @param[in]   comment  LSC Credential comment.
+ * @param[in]   session   Pointer to GNUTLS session.
+ * @param[in]   name      Name of LSC Credential.
+ * @param[in]   login     Login associated with name.
+ * @param[in]   password  Password, or NULL for autogenerated credentials.
+ * @param[in]   comment   LSC Credential comment.
+ * @param[out]  uuid      Either NULL or address for UUID of created credential.
  *
- * @return 0 on success, -1 on error.
+ * @return 0 on success, -1 or OMP response code on error.
  */
 int
 omp_create_lsc_credential (gnutls_session_t* session,
                            const char* name,
                            const char* login,
-                           const char* comment)
+                           const char* password,
+                           const char* comment,
+                           char** uuid)
 {
   int ret;
 
   /* Create the OMP request. */
 
   gchar* new_task_request;
-  if (comment)
-    new_task_request = g_strdup_printf ("<create_lsc_credential>"
-                                        "<name>%s</name>"
-                                        "<login>%s</login>"
-                                        "<comment>%s</comment>"
-                                        "</create_lsc_credential>",
-                                        name,
-                                        login,
-                                        comment);
+  if (password)
+    {
+      if (comment)
+        new_task_request = g_markup_printf_escaped ("<create_lsc_credential>"
+                                                    "<name>%s</name>"
+                                                    "<login>%s</login>"
+                                                    "<password>%s</password>"
+                                                    "<comment>%s</comment>"
+                                                    "</create_lsc_credential>",
+                                                    name,
+                                                    login,
+                                                    password,
+                                                    comment);
+      else
+        new_task_request = g_markup_printf_escaped ("<create_lsc_credential>"
+                                                    "<name>%s</name>"
+                                                    "<login>%s</login>"
+                                                    "<password>%s</password>"
+                                                    "</create_lsc_credential>",
+                                                    name,
+                                                    login,
+                                                    password);
+    }
   else
-    new_task_request = g_strdup_printf ("<create_lsc_credential>"
-                                        "<name>%s</name>"
-                                        "<login>%s</login>"
-                                        "</create_lsc_credential>",
-                                        name,
-                                        login);
+    {
+      if (comment)
+        new_task_request = g_markup_printf_escaped ("<create_lsc_credential>"
+                                                    "<name>%s</name>"
+                                                    "<login>%s</login>"
+                                                    "<comment>%s</comment>"
+                                                    "</create_lsc_credential>",
+                                                    name,
+                                                    login,
+                                                    comment);
+      else
+        new_task_request = g_markup_printf_escaped ("<create_lsc_credential>"
+                                                    "<name>%s</name>"
+                                                    "<login>%s</login>"
+                                                    "</create_lsc_credential>",
+                                                    name,
+                                                    login);
+    }
 
   /* Send the request. */
 
@@ -1748,36 +2182,29 @@ omp_create_lsc_credential (gnutls_session_t* session,
   g_free (new_task_request);
   if (ret) return -1;
 
-  return check_response (session);
+  ret = omp_read_create_response (session, uuid);
+  if (ret == 201)
+    return 0;
+  return ret;
 }
 
 /**
  * @brief Delete a LSC credential.
  *
  * @param[in]   session     Pointer to GNUTLS session.
- * @param[in]   name        Name of LSC credential.
+ * @param[in]   uuid        UUID of LSC credential.
  *
  * @return 0 on success, -1 on error.
  */
 int
 omp_delete_lsc_credential (gnutls_session_t* session,
-                           const char* name)
+                           const char* id)
 {
-  int ret;
-
-  /* Create the OMP request. */
-
-  gchar* new_task_request;
-  new_task_request = g_strdup_printf ("<delete_lsc_credential>"
-                                      "<name>%s</name>"
-                                      "</delete_lsc_credential>",
-                                      name);
-
-  /* Send the request. */
-
-  ret = openvas_server_send (session, new_task_request);
-  g_free (new_task_request);
-  if (ret) return -1;
+  if (openvas_server_sendf (session,
+                            "<delete_lsc_credential lsc_credential_id=\"%s\"/>",
+                            id)
+      == -1)
+    return -1;
 
   return check_response (session);
 }
@@ -1802,17 +2229,17 @@ omp_create_agent (gnutls_session_t* session,
 
   gchar* new_task_request;
   if (comment)
-    new_task_request = g_strdup_printf ("<create_agent>"
-                                        "<name>%s</name>"
-                                        "<comment>%s</comment>"
-                                        "</create_agent>",
-                                        name,
-                                        comment);
+    new_task_request = g_markup_printf_escaped ("<create_agent>"
+                                                "<name>%s</name>"
+                                                "<comment>%s</comment>"
+                                                "</create_agent>",
+                                                name,
+                                                comment);
   else
-    new_task_request = g_strdup_printf ("<create_agent>"
-                                        "<name>%s</name>"
-                                        "</create_agent>",
-                                        name);
+    new_task_request = g_markup_printf_escaped ("<create_agent>"
+                                                "<name>%s</name>"
+                                                "</create_agent>",
+                                                name);
 
   /* Send the request. */
 
@@ -1840,10 +2267,10 @@ omp_delete_agent (gnutls_session_t* session,
   /* Create the OMP request. */
 
   gchar* new_task_request;
-  new_task_request = g_strdup_printf ("<delete_agent>"
-                                      "<name>%s</name>"
-                                      "</delete_agent>",
-                                      name);
+  new_task_request = g_markup_printf_escaped ("<delete_agent>"
+                                              "<name>%s</name>"
+                                              "</delete_agent>",
+                                              name);
 
   /* Send the request. */
 
@@ -1872,15 +2299,14 @@ omp_get_nvt_details_503 (gnutls_session_t* session, const char * oid,
   int ret;
 
   if (oid)
-    request = g_strdup_printf ("<get_nvts"
-                               " nvt_oid=\"%s\""
-                               " details=\"1\""
-                               " preferences=\"1\"/>",
-                               oid);
+    request = g_markup_printf_escaped ("<get_nvts"
+                                       " nvt_oid=\"%s\""
+                                       " details=\"1\""
+                                       " preferences=\"1\"/>",
+                                       oid);
   else
     request = g_strdup ("<get_nvts"
                         " details=\"1\""
-                        " timeout=\"1\""
                         " preference_count=\"1\"/>");
 
   ret = get_omp_response_503 (session, request, response);
@@ -1889,3 +2315,61 @@ omp_get_nvt_details_503 (gnutls_session_t* session, const char * oid,
 
   return ret;
 }
+
+/**
+ * @brief Get system reports.
+ *
+ * @param[in]  session  Pointer to GNUTLS session.
+ * @param[in]  name     Name of system report.  NULL for all.
+ * @param[in]  brief    Whether to request brief response.
+ * @param[out] reports  Reports return.  On success contains GET_SYSTEM_REPORTS
+ *                      response.
+ *
+ * @return 0 on success, 1 on failure, -1 on error.
+ */
+int
+omp_get_system_reports (gnutls_session_t* session, const char* name, int brief,
+                        entity_t *reports)
+{
+  int ret;
+  const char *status_code;
+
+  if (name)
+    {
+      if (openvas_server_sendf (session,
+                                "<get_system_reports name=\"%s\" brief=\"%i\"/>",
+                                name,
+                                brief)
+          == -1)
+        return -1;
+    }
+  else if (openvas_server_sendf (session,
+                                 "<get_system_reports brief=\"%i\"/>",
+                                 brief)
+           == -1)
+    return -1;
+
+  /* Read the response. */
+
+  *reports = NULL;
+  if (read_entity (session, reports)) return -1;
+
+  /* Check the response. */
+
+  status_code = entity_attribute (*reports, "status");
+  if (status_code == NULL)
+    {
+      free_entity (*reports);
+      return -1;
+    }
+  if (strlen (status_code) == 0)
+    {
+      free_entity (*reports);
+      return -1;
+    }
+  if (status_code[0] == '2') return 0;
+  ret = (int) strtol (status_code, NULL, 10);
+  free_entity (*reports);
+  if (errno == ERANGE) return -1;
+  return 1;
+}
