@@ -37,9 +37,12 @@
  */
 
 #include <assert.h>
+#include <errno.h>
+#include <fcntl.h>
 #include <glib.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 
 #include "xml.h"
 
@@ -358,10 +361,17 @@ handle_end_element (GMarkupParseContext * context, const gchar * element_name,
                       /* The name of the very first entity. */
                       ((entity_t) (data->first->data))->name) == 0);
       data->done = TRUE;
+      /* "Pop" the element. */
+      data->current = g_slist_next (data->current);
+    }
+  else if (data->current)
+    {
+      GSList *front;
+      /* "Pop" and free the element. */
+      front = data->current;
+      data->current = g_slist_next (data->current);
+      g_slist_free_1 (front);
     }
-  /* "Pop" the element. */
-  if (data->current)
-    data->current = g_slist_next (data->current);
 }
 
 /**
@@ -397,9 +407,11 @@ handle_error (GMarkupParseContext * context, GError * error, gpointer user_data)
 }
 
 /**
- * @brief Read an XML entity tree from the manager.
+ * @brief Try read an XML entity tree from the manager.
  *
  * @param[in]   session   Pointer to GNUTLS session.
+ * @param[in]   timeout   Server idle time before giving up, in seconds.  0 to
+ *                        wait forever.
  * @param[out]  entity    Pointer to an entity tree.
  * @param[out]  string    An optional return location for the text read
  *                        from the session.  If NULL then it simply
@@ -408,16 +420,41 @@ handle_error (GMarkupParseContext * context, GError * error, gpointer user_data)
  *                        Otherwise it points to an existing GString onto
  *                        which the text is appended.
  *
- * @return 0 success, -1 read error, -2 parse error, -3 end of file.
+ * @return 0 success, -1 read error, -2 parse error, -3 end of file, -4 timeout.
  */
 int
-read_entity_and_string (gnutls_session_t * session, entity_t * entity,
-                        GString ** string_return)
+try_read_entity_and_string (gnutls_session_t * session, int timeout,
+                            entity_t * entity, GString ** string_return)
 {
   GMarkupParser xml_parser;
   GError *error = NULL;
   GMarkupParseContext *xml_context;
   GString *string;
+  int socket;
+  time_t last_time;
+
+  /* Record the start time. */
+
+  if (time (&last_time) == -1)
+    {
+      g_message ("   failed to get current time: %s\n",
+                 strerror (errno));
+      return -1;
+    }
+
+  if (timeout > 0)
+    {
+      /* Turn off blocking. */
+
+      socket = GPOINTER_TO_INT (gnutls_transport_get_ptr (*session));
+      if (fcntl (socket, F_SETFL, O_NONBLOCK) == -1)
+        return -1;
+    }
+  else
+    /* Quiet compiler. */
+    socket = 0;
+
+  /* Setup return arg. */
 
   if (string_return == NULL)
     string = NULL;
@@ -451,7 +488,7 @@ read_entity_and_string (gnutls_session_t * session, entity_t * entity,
       ssize_t count;
       while (1)
         {
-          g_message ("   asking for %i\n", buffer_end - buffer_start);
+          g_message ("   asking for %i\n", (int) (buffer_end - buffer_start));
           count =
             gnutls_record_recv (*session, buffer_start,
                                 buffer_end - buffer_start);
@@ -460,13 +497,30 @@ read_entity_and_string (gnutls_session_t * session, entity_t * entity,
               if (count == GNUTLS_E_INTERRUPTED)
                 /* Interrupted, try read again. */
                 continue;
+              if ((timeout > 0) && (count == GNUTLS_E_AGAIN))
+                {
+                  /* Server still busy, either timeout and try read again. */
+                  if ((timeout - (time (NULL) - last_time))
+                      <= 0)
+                    {
+                      g_message ("   timeout\n");
+                      fcntl (socket, F_SETFL, 0L);
+                      return -4;
+                    }
+                  continue;
+                }
               if (count == GNUTLS_E_REHANDSHAKE)
                 /* Try again. TODO Rehandshake. */
                 continue;
               if (context_data.first && context_data.first->data)
-                free_entity (context_data.first->data);
+                {
+                  free_entity (context_data.first->data);
+                  g_slist_free_1 (context_data.first);
+                }
               if (string && *string_return == NULL)
                 g_string_free (string, TRUE);
+              if (timeout > 0)
+                fcntl (socket, F_SETFL, 0L);
               return -1;
             }
           if (count == 0)
@@ -479,15 +533,20 @@ read_entity_and_string (gnutls_session_t * session, entity_t * entity,
                   g_error_free (error);
                 }
               if (context_data.first && context_data.first->data)
-                free_entity (context_data.first->data);
+                {
+                  free_entity (context_data.first->data);
+                  g_slist_free_1 (context_data.first);
+                }
               if (string && *string_return == NULL)
                 g_string_free (string, TRUE);
+              if (timeout > 0)
+                fcntl (socket, F_SETFL, 0L);
               return -3;
             }
           break;
         }
 
-      g_message ("<= %.*s\n", count, buffer_start);
+      g_message ("<= %.*s\n", (int) count, buffer_start);
 
       if (string)
         g_string_append_len (string, buffer_start, count);
@@ -497,9 +556,14 @@ read_entity_and_string (gnutls_session_t * session, entity_t * entity,
         {
           g_error_free (error);
           if (context_data.first && context_data.first->data)
-            free_entity (context_data.first->data);
+            {
+              free_entity (context_data.first->data);
+              g_slist_free_1 (context_data.first);
+            }
           if (string && *string_return == NULL)
             g_string_free (string, TRUE);
+          if (timeout > 0)
+            fcntl (socket, F_SETFL, 0L);
           return -2;
         }
       if (context_data.done)
@@ -510,17 +574,55 @@ read_entity_and_string (gnutls_session_t * session, entity_t * entity,
               g_message ("   End error: %s\n", error->message);
               g_error_free (error);
               if (context_data.first && context_data.first->data)
-                free_entity (context_data.first->data);
+                {
+                  free_entity (context_data.first->data);
+                  g_slist_free_1 (context_data.first);
+                }
+              if (timeout > 0)
+                fcntl (socket, F_SETFL, 0L);
               return -2;
             }
           *entity = (entity_t) context_data.first->data;
           if (string)
             *string_return = string;
+          if (timeout > 0)
+            fcntl (socket, F_SETFL, 0L);
           return 0;
         }
+
+      if ((timeout > 0) && (time (&last_time) == -1))
+        {
+          g_message ("   failed to get current time (1): %s\n",
+                     strerror (errno));
+          fcntl (socket, F_SETFL, 0L);
+          return -1;
+        }
     }
 }
 
+/**
+ * @brief Try read an XML entity tree from the manager.
+ *
+ * @param[in]   session   Pointer to GNUTLS session.
+ * @param[in]   timeout   Seconds or server idle time before giving up.  0 to
+ *                        wait forever.
+ * @param[out]  entity    Pointer to an entity tree.
+ * @param[out]  string    An optional return location for the text read
+ *                        from the session.  If NULL then it simply
+ *                        remains NULL.  If a pointer to NULL then it points
+ *                        to a freshly allocated GString on successful return.
+ *                        Otherwise it points to an existing GString onto
+ *                        which the text is appended.
+ *
+ * @return 0 success, -1 read error, -2 parse error, -3 end of file, -4 timeout.
+ */
+int
+read_entity_and_string (gnutls_session_t * session, entity_t * entity,
+                        GString ** string_return)
+{
+  return try_read_entity_and_string (session, 0, entity, string_return);
+}
+
 /**
  * @brief Read an XML entity tree from the manager.
  *
@@ -570,6 +672,22 @@ read_string (gnutls_session_t * session, GString ** string)
   return ret;
 }
 
+/**
+ * @brief Try read an XML entity tree from the manager.
+ *
+ * @param[in]   session   Pointer to GNUTLS session.
+ * @param[in]   timeout   Server idle time before giving up, in seconds.  0 to
+ *                        wait forever.
+ * @param[out]  entity    Pointer to an entity tree.
+ *
+ * @return 0 success, -1 read error, -2 parse error, -3 end of file.
+ */
+int
+try_read_entity (gnutls_session_t * session, int timeout, entity_t * entity)
+{
+  return try_read_entity_and_string (session, timeout, entity, NULL);
+}
+
 /**
  * @brief Read an XML entity tree from the manager.
  *
@@ -581,7 +699,79 @@ read_string (gnutls_session_t * session, GString ** string)
 int
 read_entity (gnutls_session_t * session, entity_t * entity)
 {
-  return read_entity_and_string (session, entity, NULL);
+  return try_read_entity (session, 0, entity);
+}
+
+/**
+ * @brief Read an XML entity tree from a string.
+ *
+ * @param[in]   string  Input string.
+ * @param[out]  entity  Pointer to an entity tree.
+ *
+ * @return 0 success, -1 read error, -2 parse error, -3 XML ended prematurely.
+ */
+int
+parse_entity (const char *string, entity_t * entity)
+{
+  GMarkupParser xml_parser;
+  GError *error = NULL;
+  GMarkupParseContext *xml_context;
+  context_data_t context_data;
+
+  /* Create the XML parser. */
+
+  xml_parser.start_element = handle_start_element;
+  xml_parser.end_element = handle_end_element;
+  xml_parser.text = handle_text;
+  xml_parser.passthrough = NULL;
+  xml_parser.error = handle_error;
+
+  context_data.done = FALSE;
+  context_data.first = NULL;
+  context_data.current = NULL;
+
+  /* Setup the XML context. */
+
+  xml_context =
+    g_markup_parse_context_new (&xml_parser, 0, &context_data, NULL);
+
+  /* Parse the string. */
+
+  g_markup_parse_context_parse (xml_context, string, strlen (string), &error);
+  if (error)
+    {
+      g_error_free (error);
+      if (context_data.first && context_data.first->data)
+        {
+          free_entity (context_data.first->data);
+          g_slist_free_1 (context_data.first);
+        }
+      return -2;
+    }
+  if (context_data.done)
+    {
+      g_markup_parse_context_end_parse (xml_context, &error);
+      if (error)
+        {
+          g_message ("   End error: %s\n", error->message);
+          g_error_free (error);
+          if (context_data.first && context_data.first->data)
+            {
+              free_entity (context_data.first->data);
+              g_slist_free_1 (context_data.first);
+            }
+          return -2;
+        }
+      *entity = (entity_t) context_data.first->data;
+      g_slist_free_1 (context_data.first);
+      return 0;
+    }
+  if (context_data.first && context_data.first->data)
+    {
+      free_entity (context_data.first->data);
+      g_slist_free_1 (context_data.first);
+    }
+  return -3;
 }
 
 /**
@@ -863,3 +1053,22 @@ compare_entities (entity_t entity1, entity_t entity2)
   g_message ("  compare failed number of entities (%s)\n", entity1->name);
   return 1;
 }
+
+/**
+ * @brief Count the number of entities.
+ *
+ * @param[in]  entities  Entities.
+ *
+ * @return Number of entities.
+ */
+int
+xml_count_entities (entities_t entities)
+{
+  int count = 0;
+  while (first_entity (entities))
+    {
+      entities = next_entities (entities);
+      count++;
+    }
+  return count;
+}
